@@ -124,7 +124,7 @@ default_sso_settings = {
 }
 
 MAILCHIMP_REQUIRED_CONFIGS = ["MAILCHIMP_SECRET_KEY", "MAILCHIMP_RESET_PASS_TEMPLATE",
-                              "MAILCHIMP_CONFIRMATION_TEMPLATE", "MAILCHIMP_SECRET_KEY"]
+                              "MAILCHIMP_CONFIRMATION_TEMPLATE"]
 
 SENDINBLUE_REQUIRED_CONFIGS = ["SENDINBLUE_API_KEY", "SENDINBLUE_RESET_PASS_TEMPLATE",
                                "SENDINBLUE_CONFIRMATION_TEMPLATE"]
