@@ -1,7 +1,7 @@
 from django.urls import path
 from rest_framework.routers import DefaultRouter
 
-from drf_auth_service.authentication.views import LoginViewSet, EBSTokenRefreshView
+from drf_auth_service.authentication.views import EBSTokenRefreshView, TokenByCookieView
 from drf_auth_service.settings import settings
 from drf_auth_service.socials.views import social_login
 
@@ -13,5 +13,6 @@ router.register(r'authentication', settings.VIEWS.AUTHENTICATION_VIEWS, basename
 urlpatterns = router.urls + [
     path('authentication/login', settings.VIEWS.AUTHENTICATION_LOGIN_VIEWS.as_view(), name='authentication-login'),
     path('authentication/oauth', social_login, name='social_login'),
-    path('authentication/refresh', EBSTokenRefreshView.as_view(), name='authentication-refresh')
+    path('authentication/refresh', EBSTokenRefreshView.as_view(), name='authentication-refresh'),
+    path('authentication/cookie', TokenByCookieView.as_view(), name='cookie-refresh'),
 ]
